@@ -6,7 +6,7 @@ void launch(int port, char *s)
 {
     int len = 8 + strlen("http://127.0.0.1:") + strlen(s);
     char *buff = malloc(len);
-    snprintf(buff, len, "http://127.0.0.1:%d/%s", port, s);
+    _snprintf(buff, len, "http://127.0.0.1:%d/%s", port, s);
     ShellExecute(NULL, "open", buff, NULL, NULL, SW_SHOWNORMAL);
     free(buff);
 }
